#!/usr/bin/python
# 
# Copyright (C) 2009, Intel Corporation.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.  
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307 USA.
#
# Authors:
#              Hao, Chen <hao.h.chen@intel.com>
#


import sys
import os

sys.path.append('../../tetj/')
from tetj import *

from kernel_ver import *
from kernel_chkcfg import *

# Test body
def _test():
    # Check command line parameters
    if (len(sys.argv) == 3) and (sys.argv[1] == '-j'):
        journal_file = sys.argv[2]
    else:
        sys.stderr.write('Usage: %s -j <journal file>\n' % sys.argv[0])
        sys.exit(1)

    try:
	journal = Journal(journal_file, 'Moblin Compliance Test')
    except:
        sys.stderr.write('Cannot create journal file : %s\n' % journal_file)
	sys.exit(1)

    journal.add_config('VSX_NAME=mobline compliance test suites (%s)' % journal.machine)
    journal.config_end()
  
    # Check kernel version
    # ==========================

    journal.testcase_start('kernel_check_version')
    journal.purpose_start()
    info = 'Checked requirement: kernel version'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_version(journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()
    journal.testcase_end()
 
    # Check kernel config flags
    # =============================
    journal.testcase_start('kernel_chkcfg')

    # Check config flag: CONFIG_NO_HZ
    # --------------------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_NO_HZ'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_NO_HZ=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()
 
    # Check config flag: CONFIG_HPET_TIMER
    # -------------------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_HPET_TIMER'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_HPET_TIMER=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()
  
    # Check config flag: CONFIG_SMP
    # -------------------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_SMP'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_SMP=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()

    # Check config flag: CONFIG_SCHED_SMT
    # -------------------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_SCHED_SMT'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_SCHED_SMT=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()
 
    # Check config flag: 
    # - CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND
    # - CONFIG_CPU_FREQ_GOV_ONDEMAND
    # -------------------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()

    journal.purpose_start()
    info = 'Checked requirement: CONFIG_CPU_FREQ_GOV_ONDEMAND'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_CPU_FREQ_GOV_ONDEMAND=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()

    # Check config flag: 
    # - CONFIG_CPU_IDLE
    # - CONFIG_CPU_IDLE_GOV_MENU 
    # --------------------------
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_CPU_IDLE'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_CPU_IDLE=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()
    
    journal.purpose_start()
    info = 'Checked requirement: CONFIG_CPU_IDLE_GOV_MENU'
    ret = TETJ_FAIL
    try:
        ret = check_kernel_cfg_flags('CONFIG_CPU_IDLE_GOV_MENU=y', journal)
    except:
        info += "\nException on testing"
    journal.testcase_info(0, 0, 0, info)
    journal.result(ret)
    journal.purpose_end()

    journal.testcase_end()    
    journal.close()


if __name__ == '__main__':
    _test()
