#!/usr/bin/python
# 
# Copyright (C) 2009, Intel Corporation.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.  
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307 USA.
#
# Authors:
#              Hao, Chen <hao.h.chen@intel.com>
#

import sys
import os
import re

sys.path.append('../../tetj/')
from tetj import *

def check_kernel_version(journal = None):
    # Required kernel version
    required_kernel_version = (2, 6, 30)
    info = 'Required kernel version: %s' % str(required_kernel_version[0])
    index = 1
    len_required_ver = len(required_kernel_version)
    while index < len_required_ver:
        info += '.' + str(required_kernel_version[index])
        index += 1
 
    # Get current kernel version
    current_kernel_version_str = ((os.uname())[2]).split('-')[0] 
    info += '\nCurrent kernel version: %s' % current_kernel_version_str
    
    info += '\nGrep \"\d+\.\d+\.\d+\" from the version'
    e=re.compile("\d+\.\d+\.\d+")
    m=e.findall(current_kernel_version_str)
    
    if m == []:
        ret = TETJ_UNTESTED
    else:
        info += "\nPure version: %s"%(m[0])
        os_uname_list = m[0].split('.')
        current_kernel_version = []
        for sub_ver in os_uname_list:
    	    try:
                current_kernel_version.append(int(sub_ver))
            except ValueError:
                return TETJ_UNTESTED
    
        len_current_ver = len(current_kernel_version)
     
        # Compare versions
        ret = TETJ_PASS
        len_to_compare = min(len_required_ver, len_current_ver)
        for i in range(len_to_compare):
    	    if current_kernel_version[i] < required_kernel_version[i]:
    	        ret = TETJ_WARNING
                break
            if len_to_compare < len_required_ver:
                ret = TETJ_WARNING

    # Output test info  
    if ret == TETJ_UNTESTED:
        info += '\nKernel version checked result: UNTESTED. Please check manually'
    elif ret == TETJ_WARNING:
        info += '\nKernel version check result: WARNING. It\'s recommended that kernel version >= 2.6.30'
    elif ret == TETJ_PASS:
        info += '\nKernel version checked result: PASS'

    print info 

    if journal != None:
        journal.testcase_info(0, 0, 0, info)

    return ret

if __name__ == '__main__':
    check_kernel_version()
